summaryrefslogtreecommitdiff
path: root/src/mongo/db/commands/current_op_common.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/commands/current_op_common.h')
-rw-r--r--src/mongo/db/commands/current_op_common.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/commands/current_op_common.h b/src/mongo/db/commands/current_op_common.h
index 8331f44d990..31ff95ac764 100644
--- a/src/mongo/db/commands/current_op_common.h
+++ b/src/mongo/db/commands/current_op_common.h
@@ -70,11 +70,11 @@ private:
virtual void modifyPipeline(std::vector<BSONObj>* pipeline) const {};
/**
* Runs the aggregation specified by the supplied AggregateCommand, returning a CursorResponse
* if successful or a Status containing the error otherwise.
*/
- virtual StatusWith<CursorResponse> runAggregation(OperationContext* opCtx,
- const AggregateCommand& request) const = 0;
+ virtual StatusWith<CursorResponse> runAggregation(
+ OperationContext* opCtx, const AggregateCommandRequest& request) const = 0;
/**
* Allows overriders to optionally write additional data to the response object before the final
@@ -70,11 +70,11 @@ private:
virtual void modifyPipeline(std::vector<BSONObj>* pipeline) const {};
/**
- * Runs the aggregation specified by the supplied AggregateCommand, returning a CursorResponse
- * if successful or a Status containing the error otherwise.
+ * Runs the aggregation specified by the supplied AggregateCommandRequest, returning a
+ * CursorResponse if successful or a Status containing the error otherwise.
*/